QYPlayerPlaybackRate class

Annotations

Constructors

QYPlayerPlaybackRate(String label, double? value)
播放倍速对象
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
当前倍速的标签 如: 1.0X
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
当前倍速的倍速值 如: 1.0
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited