VideoControllerProvider class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
enterFullscreen()
→ void
-
全屏
-
exitFullscreen()
→ void
-
退出全屏
-
loadVideo({String? videoUrl, bool? autoplay, bool? loop})
→ void
-
加载视频
videoUrl 视频地址
autoplay 是否自动播放
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
override
-
onReady(dynamic listener())
→ void
-
监听是否准备好
listener 回调
-
pause()
→ void
-
暂停
-
play()
→ void
-
播放
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
seekTo({required int currentTime})
→ void
-
跳转
currentTime 当前时间
-
toggleMuted()
→ void
-
静音
-
togglePlay()
→ void
-
切换播放
-
toString()
→ String
-
A string representation of this object.
inherited