QYPlayerResolution class
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
当前分辨率的高度
final
- label → String
-
当前分辨率的标签
如: 超清
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sublabel → String
-
当前分辨率的子标签
如: 1080P
final
- url → String
-
当前分辨率的链接
final
- width → double?
-
当前分辨率的宽度
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited