QYPlayerWidget enum
Values
- poster → const QYPlayerWidget
-
播放器控件 海报
- bigPlay → const QYPlayerWidget
-
大播放按钮
- progress → const QYPlayerWidget
-
点播播放器的进度条
- volume → const QYPlayerWidget
-
音量按钮
- fullscreen → const QYPlayerWidget
-
全屏按钮
- playbackRate → const QYPlayerWidget
-
倍速按钮
- resolution → const QYPlayerWidget
-
画质按钮
- currentTime → const QYPlayerWidget
-
播放进度
- totalTime → const QYPlayerWidget
-
总时长
- time → const QYPlayerWidget
-
播放进度 + 总时长
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QYPlayerWidget> - A constant List of the values in this enum, in order of their declaration.